class UserHistory
  include Singleton
  include Cassandra::Constants

  MAX_COUNT=100
  COUNT=10

  def self.setup(options)
    @@host = options.delete(:host)
    @@keyspace = options.delete(:keyspace)
    @@options = options
  end

  def initialize
    @cassandra = Cassandra.new(@@keyspace, @@host, @@options)
  end

  def add(shop_id, user_id, item_id)
    column = {SimpleUUID::UUID.new => item_id.to_s}
    option = {:consistency => ONE}
    @cassandra.insert(:UserHistory,
                      row_key(shop_id, user_id),
                      column, option)
  end

  def get(shop_id, user_id)
    options = {
      :reversed => true, :consistency => QUORUM,
      :count => MAX_COUNT
    }
    columns = @cassandra.get(:UserHistory,
                             row_key(shop_id, user_id),
                             options)
    item_ids = columns.values.map{|s| s.to_i}
    return item_ids.uniq[0, COUNT]
  end

  # for rspec
  def setup?
    @@host.present?
  end

  # for rspec
  def clear(shop_id, user_id)
    @cassandra.remove(:UserHistory, row_key(shop_id, user_id))
  end

  private
  def row_key(sid, uid)
    uid.to_s + "@" + sid.to_s
  end
end
